EditArea documentation

# Credits

## Special thanks

I would like to make a special thanks to TinyMCE developpers. I have taken some of their WYSIWYG editor functions (managing the toolbar buttons), and it give me inspiration for some point (gzip compression, translation, documentation) of my project.

## Contributors

These are the people that have contributed in some way to the EditArea project. If you feel we are missing someone please inform me right away and I will correct this in future versions of EditArea.

- Global help
  - Gildas Noël
  - Spellcoder
- Languages translation
  - Olaf Brambrink & Felix Riesterer & Christoph Pinkel (Deutsh)
  - Peter Klein (Danish)
  - Leonardo Sapucaia (Portuguese)
  - Ishitoya Kentaro (Japanese)
  - Piotr Furman (Polish)
  - Luciano Vernaschi (Italian)
  - Ivan Vucica and Davor Cihlar (Croatian)
  - Garito (Spanish)
  - Gabriel Schwardy (Slovak)
  - Olivier (Esperento)
  - Janne Mäntyharju (Finnish)
  - Abentian (Simplified chinese)
  - Valentin Hristov (Bulgarian)
- Syntax definitions
  - Martin Gottlieb (VB)
  - Ivan Vucica and Davor Cihlar (Basic, C, CPP, Pascal and Brainfuck)
  - Philippe Lewicki (SQL)
  - Pavle Ggardijan (Robots.txt)
  - Miladin Joksic (T-SQL)
  - Christoph Pinkel (Perl)
  - Max Leynov (Coldfusion)
  - Dawson Goodel (Java)
- Donation
  - Jupiter